==> log2html-0.2.32-sources.jar: okw/log/log2html/LogTestcase.java <==
/*
==============================================================================
  Author: Zoltán Hrabovszki <zh@openkeyword.de>

  Copyright © 2012 - 2020, IT-Beratung Hrabovszki
  www.OpenKeyWord.de
============================================================================== 

This file is part of OpenKeyWord.

OpenKeyWord is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

OpenKeyWord is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with OpenKeyWord.  If not, see <http://www.gnu.org/licenses/>.

Diese Datei ist Teil von OpenKeyWord.

OpenKeyWord ist Freie Software: Sie können es unter den Bedingungen
der GNU General Public License, wie von der Free Software Foundation,
Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
veröffentlichten Version, weiterverbreiten und/oder modifizieren.

OpenKeyWord wird in der Hoffnung, dass es nützlich sein wird, aber
OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
Siehe die GNU General Public License für weitere Details.

Sie sollten eine Kopie der GNU General Public License zusammen mit 
OpenKeyWord erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
*/

package okw.log.log2html;

public class LogTestcase extends LogBaseNode
{

    private String name = "";
    private String type = "TestCase";
    
	protected LogTestcase( LogBase Parent, String fpsTestcaseName )
	{
		setParent(Parent);
		myID = AllCount;
				
		this.name = fpsTestcaseName;
		
		
		// inkrementieren TestcaseCount
		this.TestcaseCount();
	}
	
	
  @Override
  protected void ErrorCount()
  {
      ErrorCount++;
      
      this.TestcaseFail();

      this.bError = true;
      
      if ( myParent != null)
      {
          myParent.ErrorCount();
      }
  }
  
  
  @Override
  protected void ExceptionCount()
  {
      ExceptionCount++;

      this.TestcaseFail();
      
      this.bException = true;
      
      if ( myParent != null)
      {
          myParent.ExceptionCount();
      }
  }
  
  @Override
  protected void TestcaseFail()
  {
      if ( ! (this.bError || this.bException ) )
         myParent.TestcaseFail();
  }
  
  
  @Override
  protected String getJSONNodeProperties()
  {
      StringBuilder myJSON = new StringBuilder();
      
      myJSON.append(this.jsonElementComma( "name", this.name ));
      myJSON.append(this.jsonElementComma( "type", this.type ));
      
      return myJSON.toString();
  }
}

==> log2html-0.2.39-sources.jar: okw/log/log2html/LogTestcase.java <==
/*
==============================================================================
  Author: Zoltán Hrabovszki <zh@openkeyword.de>

  Copyright © 2012 - 2020, IT-Beratung Hrabovszki
  www.OpenKeyWord.de
============================================================================== 

This file is part of OpenKeyWord.

OpenKeyWord is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

OpenKeyWord is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with OpenKeyWord.  If not, see <http://www.gnu.org/licenses/>.

Diese Datei ist Teil von OpenKeyWord.

OpenKeyWord ist Freie Software: Sie können es unter den Bedingungen
der GNU General Public License, wie von der Free Software Foundation,
Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
veröffentlichten Version, weiterverbreiten und/oder modifizieren.

OpenKeyWord wird in der Hoffnung, dass es nützlich sein wird, aber
OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
Siehe die GNU General Public License für weitere Details.

Sie sollten eine Kopie der GNU General Public License zusammen mit 
OpenKeyWord erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
*/

package okw.log.log2html;

public class LogTestcase extends LogBaseNode
{

    //private String info = "";
    private String type = "TestCase";
    
	protected LogTestcase( LogBase Parent, String fpsTestcaseName )
	{
		setParent(Parent);
		myID = AllCount;
				
		this.Info = fpsTestcaseName;
		
		
		// inkrementieren TestcaseCount
		this.TestcaseCount();
	}
	
	
  @Override
  protected void ErrorCount()
  {
      ErrorCount++;
      
      this.TestcaseFail();

      this.bError = true;
      
      if ( myParent != null)
      {
          myParent.ErrorCount();
      }
  }
  
  
  @Override
  protected void ExceptionCount()
  {
      ExceptionCount++;

      this.TestcaseFail();
      
      this.bException = true;
      
      if ( myParent != null)
      {
          myParent.ExceptionCount();
      }
  }
  
  @Override
  protected void TestcaseFail()
  {
      if ( ! (this.bError || this.bException ) )
         myParent.TestcaseFail();
  }
  
  
  @Override
  protected String getJSONNodeProperties()
  {
      StringBuilder myJSON = new StringBuilder();
      
      myJSON.append(this.jsonElementComma( "name", this.Info ));
      myJSON.append(this.jsonElementComma( "type", this.type ));
      
      return myJSON.toString();
  }
}
